@@ -10,7 +10,7 @@ use File::Copy;
 use Encode::Locale;
 use Encode;
 
-our $VERSION = 0.43;
+our $VERSION = 0.44;
 
 sub new {
   my ( $self, %opt ) = @_;
@@ -56,8 +56,8 @@ sub get_novel {
     : ( $novel_ref->{item_num} || scalar( @{ $novel_ref->{item_list} } ) );
 
   my $dst_f = $self->{packer}->main( $novel_ref, \%o );
-  $dst_f = decode(locale=>$dst_f);
-  print "info: $novel_ref->{writer}-$novel_ref->{book}-$last_item_num\noutput: $dst_f\nlast_item_num: $last_item_num\n" if ( $o{verbose} );
+  my $dst_fname = decode(locale=>$dst_f);
+  print encode(locale=>"info: $novel_ref->{writer}-$novel_ref->{book}-$last_item_num\noutput: $dst_fname\nlast_item_num: $last_item_num\n") if ( $o{verbose} );
     
   return wantarray ? ( $dst_f, $novel_ref ) : $dst_f;
 } ## end sub get_novel
